/* Auspice functions.
 *
 * Auspice Services is copyright (c) 2000-2001 In Mean.
 *     E-mail: <inmean@pleaselook.com>
 *
 * This program is free but copyrighted software; see the file COPYING for
 * details.
 */

#include "../inc/services.h"
#include "../inc/timeout.h"
#include "bs-help.c"

static int nhostline = 0;
static int hostline_size = 0;
// static int nauthline = 0;
// static int auth_size = 0;
static struct s_hline {
	char *nick;
	char *host;
	char who[NICKMAX];
	long reserved[4];
} *s_hlines = NULL;

/*
static struct snauth {
    char *nick;
    char *adder;
    char *chans;
    int atype; 
    int access; 
    int action; 
    char a;     
    char b;
    char c;
    time_t time_added;
} *snauth = NULL;
*/

// static void do_iihelp(const char *source);
static void do_agenthelp(const char *source);
static void do_agentset(const char *source);
// static void do_list_auth(const char *source);

int del_hostline(const char *nick);
// void save_auth_db(void);
// void load_auth_db(void);
// void do_add_auth(char *adder, char *nick, char *chan, int types);
void load_hline_db(void);
void save_hline_db(void);
void do_hostline(const char *nick);
void hostserv(const char *source, char *buf);
void agent(const char *source, char *buf);
void servicesX(const char *source, char *buf);
void servicesW(const char *source, char *buf);

/*************************************************************************/
void load_hline_db(void)
{
    FILE *f;
    int i;

    if (!(f = open_db(s_HostServ, HLINE_DB, "r")))
        return;

    switch (i = get_file_version(f, HLINE_DB)) {
      case 5:
        nhostline = fgetc(f) * 256 + fgetc(f);
        if (nhostline < 8)
            hostline_size = 16;
        else
            hostline_size = 2*nhostline;
        s_hlines = smalloc(sizeof(*s_hlines) * hostline_size);
        if (!nhostline) {
            fclose(f);
            return;
        }
        if (nhostline != fread(s_hlines, sizeof(*s_hlines), nhostline, f))
            fatal_perror("Read error on %s", HLINE_DB);
        for (i = 0; i < nhostline; i++) {
            s_hlines[i].nick = read_string(f, HLINE_DB);
            s_hlines[i].host = read_string(f, HLINE_DB);
        }
        break;
      default:
        fatal("Unsupported version (%d) on %s", i, HLINE_DB);
    } /* switch (version) */

    close_db(f, HLINE_DB);
}
/***********************************************************/

void save_hline_db(void)
{
    FILE *f;
    int i, count = 0;

    f = open_db("HOSTSERV", HLINE_DB, "w");
    fputc(nhostline/256, f);
    fputc(nhostline & 255, f);
    if (fwrite(s_hlines, sizeof(*s_hlines), nhostline, f) != nhostline)
        fatal_perror("Write error on %s", HLINE_DB);
    for (i = 0; i < nhostline; i++) {
        write_string(s_hlines[i].nick, f, HLINE_DB);
        write_string(s_hlines[i].host, f, HLINE_DB);
    }
    close_db(f, HLINE_DB);

}

/**********************************************************/

int is_hostline(const char *nick)
{
    NickInfo *ni;
    int i;

    for (i = 0; i < nhostline; i++) {
        if (stricmp(s_hlines[i].nick,nick) == 0) {
            return 1;
        }
    }
    return 0;
}

/*********************************************************/
void do_hostline(const char *nick)
{
    NickInfo *ni;
    int i;
    for (i = 0; i < nhostline; i++) {
        if (stricmp(s_hlines[i].nick,nick) == 0) {
	    send_cmd(s_Agent,"CHGHOST %s %s",nick,s_hlines[i].host);
	    return;
        }
    }
    return;
}
/**********************************************************/
int del_hostline(const char *nick)
{
    int i;

    for (i = 0; i < nhostline && stricmp(s_hlines[i].nick, nick) != 0; i++);
    if (i < nhostline) {
        free(s_hlines[i].nick);
        free(s_hlines[i].host);
        nhostline--;
        if (i < nhostline)
        bcopy(s_hlines+i+1, s_hlines+i, sizeof(*s_hlines) * (nhostline-i));
        return 1;
    } else {
        return 0;
    }
}
/***********************************************************/
void hostserv(const char *source, char *buf)
{
    char *cmd;
    char *s, *chan, *nick, *host, *info;
    int i;
    User *u = finduser(source);
    NickInfo *ni;

    cmd = strtok(buf, " ");

    if (!cmd) {
        return;
    } else if (stricmp(cmd, "HELP") == 0) {
        notice_list(s_HostServ, source, hostserv_help);
    } else if (stricmp(cmd, "\1PING") == 0) {
        if (!(s = strtok(NULL, "")))
            s = "\1";
        notice(s_OperServ, source, "\1PING %s", s);
    } else if (!is_services_oper(source) && !is_services_admin(source)) {
       	notice(s_HostServ, source, "Permission denied.");
       	return;
   } else if (stricmp(cmd, "LIST") == 0) {
        s = strtok(NULL, " ");
        if (!s)
            s = "*";

        notice(s_HostServ, source, "\2Current HostServ list:\2");
        for (i = 0; i < nhostline; i++) {
            if (!s || match_wild(s, s_hlines[i].nick)) {

              if (ni = findnick(s_hlines[i].nick))
                notice(s_HostServ, source, " %d) %-16s (%s) added by %s",
                                i+1, s_hlines[i].nick, s_hlines[i].host, s_hlines[i].who);
              else
                notice(s_HostServ, source, " %d) %-16s (Not Registered)",
                                i+1, s_hlines[i].nick);
            }
        }
        notice(s_HostServ,source,"\2End of List\2");

    	} else if (stricmp(cmd,"ADD") == 0) {
        nick = strtok(NULL, " ");
        host = strtok(NULL, "");
        if (!nick || !host) {
            notice(s_HostServ, source, "Syntax: \2ADD\2 <nick> <host>");
            return;
        }
        if (!findnick(nick)) {
                notice(s_OperServ, source, "Nick %s isn't registered!", nick);
                return;
        }

        for (i = 0; i < nhostline; i++) {
            if (stricmp(s_hlines[i].nick,nick) == 0) {
                notice(s_HostServ,source,"%s is already present "
                    "on the HostServ list.", nick);
                return;
            }
        }

        if (nhostline >= hostline_size) {
            if (hostline_size < 8)
                hostline_size = 8;
            else
                hostline_size *= 2;
            s_hlines = srealloc(s_hlines, sizeof(*s_hlines) *hostline_size);
        }

        if (!nhostline || (nhostline < MAX_HOSTSERV) || (MAX_HOSTSERV == 0)) {
            s_hlines[nhostline].nick = sstrdup(nick);
            s_hlines[nhostline].host = sstrdup(host);
            strscpy(s_hlines[nhostline].who, source, NICKMAX);

            notice(s_HostServ, source, "Set nick %s to HostServ", nick);
	    show_next_db(source, s_HostServ);
            wallops(s_HostServ, "Auto CHGHOST nick %s by request of %s to: %s",
                    nick, source, host);
            ++nhostline;
            if (readonly) {
                notice(s_HostServ, source,
                    "\2Notice:\2 Changes will not be saved! "
                    " Services is in read-only mode.");
            }
        }
        else {
            notice(s_HostServ,source,"Sorry, HOSTSERV list is full.");
            wallops(SERVER_NAME,"\2Warning\2: HOSTSERV(nick) list is full. (%d)", MAX_HOSTSERV);
        }

    } else if (stricmp(cmd, "INFO") == 0) {
        int i;
        nick = strtok(NULL, " ");
        info = strtok(NULL, "");

        if (!is_services_root(source)) {
            notice(s_HostServ, source, "Permission denied.");
            return;
        }

        if ((nick == NULL) || (info == NULL))
          return;

            if (strspn(nick, "1234567890") == strlen(nick) &&
                                (i = atoi(nick)) > 0 && i <= nhostline) {

                free(s_hlines[i-1].host);
                s_hlines[i-1].host = sstrdup(info);
                notice(s_HostServ, source, "CHGHOST host for %s changed to: %s",
                             s_hlines[i-1].nick, sstrdup(info));
                return;
            }

         for (i = 0; i < nhostline; i++) {
               if (stricmp(s_hlines[i].nick, nick) == 0) {

                   free(s_hlines[i].host);
                   s_hlines[i].host = sstrdup(info);
                   notice(s_HostServ, source, "CHGHOST host for %s changed to: %s",
                               s_hlines[i].nick, s_hlines[i].host);
               }
         }

    } else if (stricmp(cmd, "DEL") == 0) {
        int i;
        if (nick = strtok(NULL, " ")) {
            if (strspn(nick, "1234567890") == strlen(nick) &&
                                (i = atoi(nick)) > 0 && i <= nhostline) {
                strcpy(nick,s_hlines[i-1].nick);
            }
            if (del_hostline(nick)) {
                notice(s_HostServ, source, "%s removed from HostServ list.", nick);
                wallops(s_HostServ, "%s removed %s from the HostServ list.",
                        source, nick);
                if (readonly) {
                    notice(s_HostServ, source,
                        "\2Notice:\2 Changes will not be saved!  Services is in readonly mode.");
                }
            } else {
                notice(s_HostServ, source, "%s not found on HostServ list.",
                    nick);
            }
        } else {
            notice(s_HostServ, source, "Syntax: \2DEL\2 <nick>");
        }
    } else {
        notice(s_HostServ, source,
                "Unrecognized command \2%s\2.", cmd);
    }
}
/********************************************************************/
void agent(const char *source, char *buf)
{
    char *cmd;
    char *s, *chan, *nick, *reason, *otherc;
    int i;
    User *u = finduser(source);

    cmd = strtok(buf, " ");

   if (!is_services_root(source) && !is_services_admin(source)) {
       	notice(s_Agent, source, "Under development.");
       	return;
   }

    if (!cmd) {
        return;
    } else if (stricmp(cmd, "HELP") == 0) {
        do_agenthelp(source);
    } else if (stricmp(cmd, "OP") == 0) {
	chan = strtok(NULL, " ");
	nick = strtok(NULL, "");
	if (!chan) {
		notice(s_Agent, source, "Syntax: OP \2Channel\2 \2Nick\2");
		return;
	}
	if (!nick) {
	        change_cmode (s_Agent, chan, "+o", source);
		return;
	}
	else {
	        change_cmode (s_Agent, chan, "+o", nick);
		return;
	}

    } else if (stricmp(cmd, "NICK") == 0) {
	chan = strtok(NULL, " ");
	nick = strtok(NULL, "");
	if (!chan) {
		notice(s_Agent, source, "Syntax: NICK \2nick\2 \2nick\2");
		return;
	}
	if (!nick) {
		notice(s_Agent, source, "Syntax: NICK \2nick\2 \2nick\2");
		return;
	}
	else {
	        send_cmd (s_Agent, "SVSNICK %s %s 0", chan, nick);
		return;
	}

    } else if (stricmp(cmd, "\1PING") == 0) {
        if (!(s = strtok(NULL, "")))
            s = "\1";
        notice(s_OperServ, source, "\1PING %s", s);

    } else if (stricmp(cmd, "LISTCHANS") == 0) {
	do_aglist(source);
    } else if (stricmp(cmd, "SET") == 0) {
	do_agentset(source);
    } else if (stricmp(cmd, "INFO") == 0) {
        notice(s_Agent, source, "X         : %d", CHANX);
        notice(s_Agent, source, "WEBTV     : %d", SPRIV);
        notice(s_Agent, source, "AUTOUP    : %d", AUTOUP);
        notice(s_Agent, source, "LISTCHANS : %d", ALLOWCLIST);
        notice(s_Agent, source, "AUTOCHAN  : %s", ACHANS);
        notice(s_Agent, source, "AUTOJOIN  : %d", AUTOJOINC);
        notice(s_Agent, source, "NO MASK   : %d", NS_DACCESS);
        notice(s_Agent, source, "CJOIN     : %d", CJOIN);

    } else if (stricmp(cmd, "JOIN") == 0) {
	if (!is_services_root(source)) {
       		notice(s_Agent, source, "Permision Denied.");
	       	return;
	}
	chan = strtok(NULL, " ");
	if (!chan) {
		notice(s_Agent, source, "Syntax: JOIN \2Channel\2");
	} else {
	        send_cmd (s_Agent, "JOIN %s", chan);
        	send_cmd (s_Agent, "MODE %s +a %s", chan, s_Agent);
	}

    } else if (stricmp(cmd, "PART") == 0) {
	if (!is_services_root(source)) {
       		notice(s_Agent, source, "Permision Denied.");
		return;
	}
	chan = strtok(NULL, " ");
	if (!chan) {
		notice(s_Agent, source, "Syntax: PART \2Channel\2");
	} else {
	        send_cmd (s_Agent, "PART %s", chan);
	}

    } else if (stricmp(cmd, "KICK") == 0) {
	if (!is_services_root(source)) {
       		notice(s_Agent, source, "Permision Denied.");
		return;
	}
	chan = strtok(NULL, " ");
	nick = strtok(NULL, " ");
	reason = strtok(NULL, "");
	if ((!chan) || (!nick) || (!reason)) {
		notice(s_Agent, source, "Syntax: KICK \2Channel\2 \2nick\2 \2reason\2");
	} else {
	    send_cmd(s_Agent, "KICK %s %s :%s", chan, nick, reason);
	}

    } else if (stricmp(cmd, "EXIT") == 0) {
	if (!is_services_root(source)) {
       		notice(s_Agent, source, "Permision Denied.");
		return;
	}
	nick = strtok(NULL, " ");
	reason = strtok(NULL, "");
	if ((!nick) || (!reason)) {
		notice(s_Agent, source, "Syntax: EXIT \2nick\2 \2reason\2");
	} else {
	    send_cmd(s_Agent, "SVSKILL %s :%s", nick, reason);
	}

    } else {
        notice(s_Agent, source,
                "Unrecognized command \2%s\2.", cmd);
    }
}
/*****************************************************************/
static void do_agenthelp(const char *source)
{
    const char *cmd = strtok(NULL, " ");
    if (!cmd) {
        notice_list(s_Agent, source, agent_help);
    } else if (stricmp(cmd, "SET") == 0) {
        notice_list(s_Agent, source, agent_helpset);
    } else {
        notice(s_Agent, source,	"No help available for command \2%s\2.", cmd);
    notice(s_Agent, source, "\2END OF HELP\2");
    }
}
/******************************************************************/
static void do_agentset(const char *source)
{
    const char *cmd = strtok(NULL, " ");
    char *s, *chan, *nick, *reason, *otherc;
    int i;
    User *u = finduser(source);

    if (!cmd) {
        notice_list(s_Agent, source, agent_helpset);
    } else if (stricmp(cmd, "X") == 0) {
	   if (is_services_coder(source)) {
		otherc = strtok(NULL, " ");
		if (otherc) {
		if (stricmp(otherc, "ON") == 0) {
			CHANX = 1;
	      		notice(s_Agent, source, "X set access in Mark/Hold Channel.");
		} else if (stricmp(otherc, "OFF") == 0) {
			CHANX = 0;
	      		notice(s_Agent, source, "Deactivated X.");
	        } else {
	      		notice(s_Agent, source, "Syntax: SET X ON/OFF");
		} }
   	    }

    } else if ((stricmp(cmd, "SPRIV") == 0) || (stricmp(cmd, "WEBTV") == 0)) {
	   if (is_services_coder(source)) {
		otherc = strtok(NULL, " ");
		if (otherc) {
		if (stricmp(otherc, "ON") == 0) {
			SPRIV = 1;
	      		notice(s_Agent, source, "Service changed from Notice to Private Message.");
		} else if (stricmp(otherc, "OFF") == 0) {
			SPRIV = 0;
	      		notice(s_Agent, source, "Service changed from Private to Notice Message.");
	        } else {
	      		notice(s_Agent, source, "Syntax: SET WEBTV ON/OFF");
		} }
   	    }

    } else if (stricmp(cmd, "AUTOUP") == 0) {
	   if (is_services_coder(source)) {
		otherc = strtok(NULL, " ");
		if (otherc) {
		if (stricmp(otherc, "ON") == 0) {
			AUTOUP = 1;
	      		notice(s_Agent, source, "Service will update database on any change made.");
		} else if (stricmp(otherc, "OFF") == 0) {
			AUTOUP = 0;
	      		notice(s_Agent, source, "Service will update database following the time.");
	        } else {
	      		notice(s_Agent, source, "Syntax: SET AUTOUP ON/OFF");
		} }
   	    }

    } else if (stricmp(cmd, "AMASK") == 0) {
	   if (is_services_coder(source)) {
		otherc = strtok(NULL, " ");
		if (otherc) {
		if (stricmp(otherc, "ON") == 0) {
			NS_DACCESS = 1;
	      		notice(s_Agent, source, "Access mask can not be added into channel access list.");
		} else if (stricmp(otherc, "OFF") == 0) {
			NS_DACCESS = 0;
	      		notice(s_Agent, source, "Allow access mask to be added into channel access list.");
	        } else {
	      		notice(s_Agent, source, "Syntax: SET AMASK ON/OFF");
		} }
   	    }

    } else if ((stricmp(cmd, "ALLOWCLIST") == 0) || (stricmp(cmd, "LISTCHANS") == 0)) {
	   if (is_services_coder(source)) {
		otherc = strtok(NULL, " ");
		if (otherc) {
		if (stricmp(otherc, "ON") == 0) {
			ALLOWCLIST = 1;
	      		notice(s_Agent, source, "User is able to use LISTCHANS command.");
		} else if (stricmp(otherc, "OFF") == 0) {
			ALLOWCLIST = 0;
	      		notice(s_Agent, source, "LISTCHANS command are disabled.");
	        } else {
	      		notice(s_Agent, source, "Syntax: SET LISTCHANS ON/OFF");
		} }
   	    }
    } else if (stricmp(cmd, "CJOIN") == 0) {
	   if (is_services_coder(source)) {
		otherc = strtok(NULL, " ");
		if (otherc) {
		if (stricmp(otherc, "ON") == 0) {
			CJOIN = 1;
	      		notice(s_Agent, source, "User now can set ChanServ join channel.");
		} else if (stricmp(otherc, "OFF") == 0) {
			CJOIN = 0;
	      		notice(s_Agent, source, "Disable ChanServ Join option for user.");
	        } else {
	      		notice(s_Agent, source, "Syntax: SET CJOIN ON/OFF");
		} }
   	    }
    } else if (stricmp(cmd, "AUTOJOIN") == 0) {
	   if (is_services_coder(source)) {
		otherc = strtok(NULL, " ");
		if (otherc) {
		if (stricmp(otherc, "ON") == 0) {
//			ACHANS = strtok(NULL, " ");
//			if ((!ACHANS) || !(*ACHANS == '#')) {
//		      		notice(s_Agent, source, "Syntax: SET AUTOJOIN ON/OFF #<channel>");
//			} else {
				AUTOJOINC = 1;
		      		notice(s_Agent, source, "User will auto join channel %s.",ACHANS);
//			}
		} else if (stricmp(otherc, "OFF") == 0) {
			AUTOJOINC = 0;
	      		notice(s_Agent, source, "Disable auto join option.");
	        } else {
	      		notice(s_Agent, source, "Syntax: SET AUTOJOIN ON/OFF #<channel>");
		} }
   	    }
    } else  {
        notice(s_Agent, source,
                "Unrecognized command \2%s\2.", cmd);
    }
}
/******************************************************************/
void servicesX(const char *source, char *buf)
{
    char *cmd;
    char *s, *chan, *nick, *host;
    int i;
    User *u = finduser(source);

    cmd = strtok(buf, " ");

    if (!cmd) {
        return;
    } else if (stricmp(cmd, "\1PING") == 0) {
        if (!(s = strtok(NULL, "")))
            s = "\1";
        notice(s_OperServ, source, "\1PING %s", s);

/*    } else if (stricmp(cmd, "LS") == 0) {
	do_list_auth(source); */
    } else if (stricmp(cmd, "JOIN") == 0) {
	if (!is_services_root(source)) {
       		notice(s_ServicesX, source, "Permision Denied.");
	       	return;
	}
	chan = strtok(NULL, " ");
	if (!chan) {
		notice(s_ServicesX, source, "Syntax: JOIN \2Channel\2");
	} else {
	        send_cmd (s_ServicesX, "JOIN %s", chan);
        	send_cmd (s_ServicesX, "MODE %s +a %s", chan, s_ServicesX);
	}

    } else if (stricmp(cmd, "PART") == 0) {
	if (!is_services_root(source)) {
       		notice(s_ServicesX, source, "Permision Denied.");
	}
	chan = strtok(NULL, " ");
	if (!chan) {
		notice(s_ServicesX, source, "Syntax: PART \2Channel\2");
	} else {
	        send_cmd (s_ServicesX, "PART %s", chan);
	}

    } else {
/*        notice(s_ServicesX, source,
                "Unrecognized command \2%s\2.", cmd); */
    }
}

/***************************************************************/
void servicesW(const char *source, char *buf)
{
    char *cmd;
    char *s, *chan, *nick;
    int i;
    int lnset = 1;
    User *u = finduser(source);

    cmd = strtok(buf, " ");

    if (!cmd) {
	return;
    } else if (stricmp(cmd, "HELP") == 0) {
	send_cmd(s_ServicesW,"Syntax: <Country Domain>");
	return;
    } else if (stricmp(cmd, "\1PING") == 0) {
        if (!(s = strtok(NULL, "")))
            s = "\1";
        notice(s_OperServ, source, "\1PING %s", s);

    } else if (stricmp(cmd, "JOIN") == 0) {

	if (!is_services_root(source)) {
       		notice(s_ServicesW, source, "Permision Denied.");
	       	return;
	}
	chan = strtok(NULL, " ");
	if (!chan) {
		notice(s_ServicesW, source, "Syntax: JOIN \2Channel\2");
	} else {
	        send_cmd (s_ServicesW, "JOIN %s", chan);
        	send_cmd (s_ServicesW, "MODE %s +a %s", chan, s_ServicesW);
	}

    } else if (stricmp(cmd, "PART") == 0) {

	if (!is_services_root(source)) {
       		notice(s_ServicesW, source, "Permision Denied.");
	       	return;
	}
	chan = strtok(NULL, " ");
	if (!chan) {
		notice(s_ServicesW, source, "Syntax: PART \2Channel\2");
	} else {
	        send_cmd (s_ServicesW, "PART %s", chan);
	}
    } else if (stricmp(cmd, "KH") == 0) {
	send_cmd(s_ServicesW,"SWHOIS %s :is prefer to speak Khmer language.",source);
	lnset = 2;
    } else if (stricmp(cmd, "MY") == 0) {
	send_cmd(s_ServicesW,"SWHOIS %s :is prefer to speak Malay language.",source);
	lnset = 2;
    } else if (stricmp(cmd, "EN") == 0) {
	send_cmd(s_ServicesW,"SWHOIS %s :is prefer to speak English language.",source);
	lnset = 2;
    } else if (stricmp(cmd, "FR") == 0) {
	send_cmd(s_ServicesW,"SWHOIS %s :is prefer to speak French language.",source);
	lnset = 2;
    } else if (stricmp(cmd, "TH") == 0) {
	send_cmd(s_ServicesW,"SWHOIS %s :is prefer to speak Thai language.",source);
	lnset = 2;
    } else if (stricmp(cmd, "KR") == 0) {
	send_cmd(s_ServicesW,"SWHOIS %s :is prefer to speak Kreblakestanian language.",source);
	lnset = 2;
    } else {
        notice(s_ServicesW, source, "There is no \2%s\2 language support yet.", cmd);
        notice(s_ServicesW, source, "E-mail to \2auspice@pleaselook.com\2 for added.");
	lnset = 0;
    }
    if (lnset == 2)
        notice(s_ServicesW, source, "Your language mode set to \2%s\2.", cmd);
}
/***********************************************************************/
/*
void load_auth_db(void)
{
    FILE *f;
    int i;

    if (!(f = open_db(s_HostServ, AUTH_DB, "r")))
        return;

    switch (i = get_file_version(f, AUTH_DB)) {
      case 5:
        nhostline = fgetc(f) * 256 + fgetc(f);
        if (nauthline < 8)
            auth_size = 16;
        else
            auth_size = 2*nauthline;
        snauth = smalloc(sizeof(*snauth) * auth_size);
        if (!nauthline) {
            fclose(f);
            return;
        }
        if (nauthline != fread(snauth, sizeof(*snauth), nauthline, f))
            fatal_perror("Read error on %s", AUTH_DB);
        for (i = 0; i < nauthline; i++) {
            snauth[i].nick = read_string(f, AUTH_DB);
            snauth[i].adder = read_string(f, AUTH_DB);
            snauth[i].chans = read_string(f, AUTH_DB);
        }
        break;
      default:
        fatal("Unsupported version (%d) on %s", i, AUTH_DB);
    } 

    close_db(f, AUTH_DB);
} */
/************************************************************************/
/*
void save_auth_db(void)
{
    FILE *f;
    int i, count = 0;

    f = open_db(s_HostServ, AUTH_DB, "w");
    fputc(nauthline/256, f);
    fputc(nauthline & 255, f);
    if (fwrite(snauth, sizeof(*snauth), nauthline, f) != nauthline)
        fatal_perror("Write error on %s", AUTH_DB);
    for (i = 0; i < nauthline; i++) {
        write_string(snauth[i].nick, f, AUTH_DB);
        write_string(snauth[i].adder, f, AUTH_DB);
        write_string(snauth[i].chans, f, AUTH_DB);
    }
    close_db(f, AUTH_DB);
}
*/
/***********************************************************************/
/*
 void do_add_auth(char *adder, char *nick, char *chan, int types)
{

        if (nauthline >= auth_size) {
            if (auth_size < 8)
                auth_size = 8;
            else
                auth_size *= 2;
            snauth = srealloc(snauth, sizeof(*snauth) *auth_size);
        }
       notice(s_Agent, adder, "Auth will for %s on chan %s access %d", nick, chan, types);

        if (!nauthline) {
            snauth[nauthline].adder = sstrdup(adder);
            snauth[nauthline].nick = sstrdup(nick);
            snauth[nauthline].chans = sstrdup(chan);
            snauth[nauthline].access = types;
            ++nauthline;
            if (readonly) {
                notice(s_HostServ, adder,
                    "\2Notice:\2 Changes will not be saved! "
                    " Services is in read-only mode.");
            }
        } 
} */
/**************************************************************/
/*
static void do_list_auth(const char *source)
{
    char *s;
    int i;

        s = strtok(NULL, " ");
        if (!s)
            s = "*";

        notice(s_HostServ, source, "\2Current HostServ list:\2");
        for (i = 0; i < nauthline; i++) {
                notice(s_HostServ, source, " %d) chan %s level %d added by %s", i+1, snauth[i].chans, snauth[i].access, snauth[i].adder);
        }
        notice(s_HostServ,source,"\2End of List\2");
}
*/
